@@ -28,19 +28,25 @@ def STEP(stepNo:int,desc:str):
     signal.step(stepNo,desc)
 
 
-def CHECK_POINT(desc:str, condition):
+def CHECK_POINT(desc:str, condition, LogSreenWebDriverIfFail = None):
     """
     检查点
 
     参数：
-    @param desc :   检查点文字描述
+    @param desc :   检查点 文字描述
     @param condition ： 检查点 表达式
+    @param LogSreenWebDriverIfFail ： 如果检查错误，需要截屏，提供的webdirver对象
     """
 
     if condition:
         signal.checkpoint_pass(desc)
     else:
         signal.checkpoint_fail(desc)
+
+        # 如果需要截屏
+        if LogSreenWebDriverIfFail is not None:
+            SELENIUM_LOG_SCREEN(LogSreenWebDriverIfFail)
+
         raise AssertionError()
 
 def LOG_IMG(imgPath: str, width: str = None):
