@@ -22,7 +22,7 @@ def tagmatch(pattern):
 		if fnmatch.fnmatch(tag,pattern):return _B
 	return _C
 class Collector:
-	SUITE_TAGS=[_H,_M];SUITE_STS=[_I,_E,_N,_O];exec_list=[];exec_table={};suite_tag_table={_H:{},_M:{}};current_case_tags=[]
+	SUITE_TAGS=[_H,_M];SUITE_STS=[_I,_E,_N,_O];exec_list=[];exec_table={};case_number=0;suite_tag_table={_H:{},_M:{}};current_case_tags=[]
 	@classmethod
 	def run(cls,casedir=_A,suitename_filters=[],casename_filters=[],tag_include_expr=_F,tag_exclude_expr=_F):
 		for (dirpath,dirnames,filenames) in os.walk(casedir):
@@ -66,6 +66,7 @@ class Collector:
 			if not meta[_A]:signal.debug(f"\n--- finally, no cases in this module , skip it.");return
 			cls.caseFilter(filepath,meta,tag_include_expr,tag_exclude_expr,suitename_filters,casename_filters)
 			if not meta[_A]:signal.debug(f"\n--- finally, no cases in this module , skip it.");return
+			cls.case_number+=len(meta[_A])
 		elif len(meta)==1:signal.debug(f"\n--- finally, no setup/teardown/tags in this module , skip it.");return
 		cls.exec_list.append(filepath);cls.exec_table[filepath]=meta
 	@classmethod
